@@ -165,7 +165,7 @@ class AkinonCloudClient:
         data = {
             "start_datetime": start_datetime.isoformat(),
             "end_datetime": end_datetime.isoformat(),
-            "page": 0,
+            "page": 1,
             "page_size": 10000,
             "applications": process_type
         }
@@ -175,7 +175,6 @@ class AkinonCloudClient:
 
     def export_project_app_logs(self, project_id, project_app_id, start_date=None, end_date=None, dates=None,
                                 applications=None):
-        query_params = {'format': "csv"}
         data = {}
 
         if start_date:
@@ -192,7 +191,7 @@ class AkinonCloudClient:
 
         return self._send_request('POST', 'project_apps_export_logs',
                                   params={"project_id": project_id, "project_app_id": project_app_id},
-                                  qs=query_params, data=data, response_format='csv')
+                                  data=data)
 
     def create_project_app(self, p_id, data):
         return self._send_request("POST", "project_apps", params={"p_id": p_id},
