@@ -4,7 +4,7 @@ from datetime import datetime, timezone, timedelta
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
 
-from ..core.exc import AkinonCLIError
+from ..core.exc import AkinonCLIError, AkinonCLIWarning
 from . import PaginationEnum
 from ..core.version import get_version
 
@@ -397,8 +397,8 @@ class ProjectApps(Controller):
             (['project_app_id'], {'help': 'Project App ID', 'action': 'store'}),
             (['-d', '--dates'], {'help': 'Dates (YYYY-MM-DD)', 'action': 'store', 'dest': 'dates', 'default': ''}),
             (['-p', '--process'], {'help': 'Process type', 'action': 'store', 'default': ''}),
-            (['-s', '--start_date'], {'help': 'Start date (YYYY-MM-DD)', 'action': 'store', 'dest': 'start_date'}),
-            (['-e', '--end_date'], {'help': 'End date (YYYY-MM-DD)', 'action': 'store', 'dest': 'end_date'}),
+            (['-s', '--start_date'], {'help': 'Start date (YYYY-MM-DD HH:MM)', 'action': 'store', 'dest': 'start_date'}),
+            (['-e', '--end_date'], {'help': 'End date (YYYY-MM-DD HH:MM)', 'action': 'store', 'dest': 'end_date'}),
         ]
     )
     def export_logs(self):
@@ -412,23 +412,29 @@ class ProjectApps(Controller):
         if dates and (start_date or end_date):
             raise AkinonCLIError("--dates and (--start_date or --end_date) filters cannot be used together.")
 
-        response = self.app.client.export_project_app_logs(
-            project_id=project_id,
-            project_app_id=project_app_id,
-            dates=dates,
-            applications=applications,
-            start_date=start_date,
-            end_date=end_date
-        )
+        if start_date and end_date:
+            try:
+                datetime.strptime(start_date, "%Y-%m-%d %H:%M")
+                datetime.strptime(end_date, "%Y-%m-%d %H:%M")
+            except:
+                raise AkinonCLIError("start_date and end_date must be in the format 'YYYY-MM-DD HH:MM'")
 
-        if not response.is_succeed or not response.data or response.status_code == 406:
-            raise AkinonCLIError("Log not found.")
+        try:
+            response = self.app.client.export_project_app_logs(
+                project_id=project_id,
+                project_app_id=project_app_id,
+                dates=dates,
+                applications=applications,
+                start_date=start_date,
+                end_date=end_date
+            )
+        except AkinonCLIError as e:
+            if e.response.status_code == 406:
+                raise AkinonCLIWarning(e.response.json()['non_field_errors'])
+            else:
+                raise
 
-        filename = "logs.csv"
-        with open(filename, "wb") as binary_file:
-            binary_file.write(response.data)
-
-        self.app.render({}, custom_text=f'log file has been created at {os.getcwd()}/{filename}', is_text=True)
+        self.app.render({}, custom_text=response.data['message'], is_text=True)
 
 
 class Addons(Controller):
