@@ -9,7 +9,7 @@ from cement.core.exc import CaughtSignal
 from akinoncli.controllers.account import Domains, Certificates
 from akinoncli.ext.output_renderer import AkinonOutputHandler
 from akinoncli.client.client import AkinonCloudClient
-from akinoncli.core.exc import AkinonCLIError
+from akinoncli.core.exc import AkinonCLIError, AkinonCLIWarning
 
 from akinoncli.controllers.base import Base
 from akinoncli.controllers.auth import Auth
@@ -134,8 +134,8 @@ def main():
             if app.debug is True:
                 import traceback
                 traceback.print_exc()
-
-
+        except AkinonCLIWarning as e:
+            app.log.warning(f'{e.message}')
         except CaughtSignal as e:
             # Default Cement signals are SIGINT and SIGTERM, exit 0 (non-error)
             print(f'\n{e}')
